==> rendition-9.10.0.tgz: package/dist_esm5/unstable/components/JellyForm/index.js <==
import * as tslib_1 from "tslib";
import * as jellyschema from 'jellyschema';
import cloneDeep from 'lodash/cloneDeep';
import isEqual from 'lodash/isEqual';
import merge from 'lodash/merge';
import omit from 'lodash/omit';
import * as React from 'react';
import { default as Form } from '../Form';
import { defaultValueForSchema, runFormulas } from './formulas';
var computeFormSchemas = function (jellySchema, uiSchema) {
    var computed = jellyschema.generateJsonAndUiSchema(jellySchema);
    return {
        schema: computed.jsonSchema,
        uiSchema: merge({}, computed.uiSchema, uiSchema),
    };
};
var JellyForm = (function (_super) {
    tslib_1.__extends(JellyForm, _super);
    function JellyForm(props) {
        var _this = _super.call(this, props) || this;
        _this.onChange = function (changeData) {
            var formData = changeData.formData;
            var schema = _this.state.schema;
            var data = cloneDeep(formData);
            var evaluate = runFormulas(schema, data);
            var startingState = defaultValueForSchema(schema);
            var result = merge(startingState, formData, evaluate);
            _this.setState({ value: result });
            if (_this.props.onFormChange) {
                _this.props.onFormChange(tslib_1.__assign({}, changeData, { formData: result }));
            }
        };
        var _a = computeFormSchemas(props.schema, props.uiSchema), schema = _a.schema, uiSchema = _a.uiSchema;
        _this.state = {
            value: props.value || defaultValueForSchema(schema),
            schema: schema,
            uiSchema: uiSchema,
        };
        return _this;
    }
    JellyForm.prototype.componentWillReceiveProps = function (nextProps) {
        if (!isEqual(this.props.value, nextProps.value)) {
            this.setState({
                value: runFormulas(this.state.schema, nextProps.value),
            });
        }
        if (!isEqual(this.props.schema, nextProps.schema) ||
            !isEqual(this.props.uiSchema, nextProps.uiSchema)) {
            var _a = computeFormSchemas(nextProps.schema, nextProps.uiSchema), schema = _a.schema, uiSchema = _a.uiSchema;
            this.setState({
                schema: schema,
                uiSchema: uiSchema,
            });
        }
    };
    JellyForm.prototype.render = function () {
        var _a = this.state, value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema;
        var options = omit(this.props, [
            'value',
            'schema',
            'uiSchema',
            'onFormChange',
        ]);
        return (React.createElement(Form, tslib_1.__assign({ value: value, schema: schema, uiSchema: uiSchema, onFormChange: this.onChange }, options)));
    };
    return JellyForm;
}(React.Component));
export default JellyForm;

==> rendition-11.16.1.tgz: package/dist_esm5/unstable/components/JellyForm/index.js <==
import { __assign, __extends } from "tslib";
import * as jellyschema from 'jellyschema';
import cloneDeep from 'lodash/cloneDeep';
import isEqual from 'lodash/isEqual';
import merge from 'lodash/merge';
import omit from 'lodash/omit';
import * as React from 'react';
import { default as Form } from '../Form';
import { defaultValueForSchema, runFormulas } from './formulas';
var computeFormSchemas = function (jellySchema, uiSchema) {
    var computed = jellyschema.generateJsonAndUiSchema(jellySchema);
    return {
        schema: computed.jsonSchema,
        uiSchema: merge({}, computed.uiSchema, uiSchema),
    };
};
var JellyForm = (function (_super) {
    __extends(JellyForm, _super);
    function JellyForm(props) {
        var _this = _super.call(this, props) || this;
        _this.onChange = function (changeData) {
            var formData = changeData.formData;
            var schema = _this.state.schema;
            var data = cloneDeep(formData);
            var evaluate = runFormulas(schema, data);
            var startingState = defaultValueForSchema(schema);
            var result = merge(startingState, formData, evaluate);
            _this.setState({ value: result });
            if (_this.props.onFormChange) {
                _this.props.onFormChange(__assign(__assign({}, changeData), { formData: result }));
            }
        };
        var _a = computeFormSchemas(props.schema, props.uiSchema), schema = _a.schema, uiSchema = _a.uiSchema;
        _this.state = {
            value: props.value || defaultValueForSchema(schema),
            schema: schema,
            uiSchema: uiSchema,
        };
        return _this;
    }
    JellyForm.prototype.componentWillReceiveProps = function (nextProps) {
        if (!isEqual(this.props.value, nextProps.value)) {
            this.setState({
                value: runFormulas(this.state.schema, nextProps.value),
            });
        }
        if (!isEqual(this.props.schema, nextProps.schema) ||
            !isEqual(this.props.uiSchema, nextProps.uiSchema)) {
            var _a = computeFormSchemas(nextProps.schema, nextProps.uiSchema), schema = _a.schema, uiSchema = _a.uiSchema;
            this.setState({
                schema: schema,
                uiSchema: uiSchema,
            });
        }
    };
    JellyForm.prototype.render = function () {
        var _a = this.state, value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema;
        var options = omit(this.props, [
            'value',
            'schema',
            'uiSchema',
            'onFormChange',
        ]);
        return (React.createElement(Form, __assign({ value: value, schema: schema, uiSchema: uiSchema, onFormChange: this.onChange }, options)));
    };
    return JellyForm;
}(React.Component));
export default JellyForm;
